#include <bits/stdc++.h>

#define FSTREAM
#define MULTITEST

using namespace std;

typedef long long ll;
typedef long double ld;

unordered_map<string, pair<string, int>> result;
const string DRAW = "draw";
const string WIN = "win";
const int INF = 1e9;

struct state {
    const int KING_MOVES = 8;
    const vector<int> king_dx = {1, 1, 1, 0, -1, -1, -1, 0};
    const vector<int> king_dy = {1, 0, -1, -1, -1, 0, 1, 1};
    const int VIZIR_MOVES = 4;
    const vector<int> vizir_dx = {1, 0, -1, 0};
    const vector<int> vizir_dy = {0, -1, 0, 1};
    const int VERBLOUD_MOVES = 8;
    const vector<int> verbloud_dx = {1, 3, 3, 1, -1, -3, -3, -1};
    const vector<int> verbloud_dy = {3, 1, -1, -3, -3, -1, 1, 3};
    string white_king, black_king, verbloud, vizir, turn;

    string get_hash() {
        return white_king + black_king + verbloud + vizir + turn;
    }

    vector<state> get_next() {
        vector<state> nexts;
        if (this->white_turn()) {
            // white king
            for (int i = 0; i < KING_MOVES; ++i) {
                state next = *this;
                next.white_king = modify(white_king, king_dx[i], king_dy[i]);
                next.turn = change(turn);
                if (next.is_valid()) {
                    nexts.push_back(next);
                }
            }
            // white vizir
            for (int i = 0; i < VIZIR_MOVES; ++i) {
                state next = *this;
                next.vizir = modify(vizir, vizir_dx[i], vizir_dy[i]);
                next.turn = change(turn);
                if (next.is_valid()) {
                    nexts.push_back(next);
                }
            }
            // white verbloud
            for (int i = 0; i < VERBLOUD_MOVES; ++i) {
                state next = *this;
                next.verbloud = modify(verbloud, verbloud_dx[i], verbloud_dy[i]);
                next.turn = change(turn);
                if (next.is_valid()) {
                    nexts.push_back(next);
                }
            }
        } else {
            // black king
            for (int i = 0; i < KING_MOVES; ++i) {
                state next = *this;
                next.black_king = modify(black_king, king_dx[i], king_dy[i]);
                next.turn = change(turn);
                if (next.is_valid()) {
                    nexts.push_back(next);
                }
            }
        }
        return nexts;
    }

    string change(string t) {
        return t == "w" ? "b" : "w";
    }

    string modify(string pos, int dx, int dy) {
        int x = pos[0] - 'a';
        int y = pos[1] - '0';
        char nx = 'a' + x + dx;
        char ny = '0' + y + dy;
        string s;
        s += nx;
        s += ny;
        return s;
    }

    bool is_figure_valid(string pos) {
        return 'a' <= pos[0] && pos[0] <= 'h' &&
               '1' <= pos[1] && pos[1] <= '8';
    }

    bool check() {
        // white vizir
        for (int i = 0; i < VIZIR_MOVES; ++i) {
            state next = *this;
            next.vizir = modify(vizir, vizir_dx[i], vizir_dy[i]);
            next.turn = change(turn);
            if (next.vizir == black_king) {
                return true;
            }
        }
        // white verbloud
        for (int i = 0; i < VERBLOUD_MOVES; ++i) {
            state next = *this;
            next.verbloud = modify(verbloud, verbloud_dx[i], verbloud_dy[i]);
            next.turn = change(turn);
            if (next.verbloud == black_king) {
                return true;
            }
        }
        return false;
    }

    bool is_valid() {
        return is_figure_valid(white_king) &&
               is_figure_valid(vizir) &&
               is_figure_valid(verbloud) &&
               is_figure_valid(black_king) &&
               !(check() && white_turn());
    }

    bool white_turn() {
        return turn == "w";
    }

    bool is_terminal() {
        if (white_turn()) {
            return false;
        }
        return this->checkmate() || this->stalemate();
    }

    bool checkmate() {
        return check() && no_black_moves();
    }

    bool stalemate() {
        return !check() && no_black_moves();
    }

    bool no_black_moves() {
        for (int i = 0; i < KING_MOVES; ++i) {
            state next = *this;
            next.black_king = modify(black_king, king_dx[i], king_dy[i]);
            next.turn = change(turn);
            if (!next.check()) {
                return false;
            }
        }
        return true;
    }

    pair<string, int> get_result() {
        if (this->checkmate()) {
            return pair<string, int>{WIN, 0};
        } else {
            return pair<string, int>{DRAW, 0};
        }
    }

    string get_crd(int i, int j) {
        string s;
        s += 'a' + i;
        s += '1' + j;
        return s;
    }

    void print() {
        for (int i = 0; i < 8; ++i) {
            for (int j = 0; j < 8; ++j) {
                auto crd = get_crd(i, j);
                if (crd == white_king) {
                    cout << "K";
                } else if (crd == black_king) {
                    cout << "k";
                } else if (crd == vizir) {
                    cout << "R";
                } else if (crd == verbloud) {
                    cout << "V";
                } else {
                    cout << ".";
                }
            }
            cout << "\n";
        }
    }
};

bool all_equals(vector<pair<string, int>> results, string result) {
    for (const auto& res : results) {
        if (res.first != result) {
            return false;
        }
    }
    return true;
}

pair<string, int> rec(state s, int depth = 0) {
    cout << "depth = " << depth << "\n";
    // s.print();
    // if (depth >= 2) {
    //     return {DRAW, 0};
    // }
    if (result.count(s.get_hash())) {
        return result[s.get_hash()];
    }
    if (s.is_terminal()) {
        pair<string, int> res = s.get_result();
        result[s.get_hash()] = res;
        return res;
    }
    vector<state> next = s.get_next();
    vector<pair<string, int>> results;
    for (state new_s : next) {
        // black king is on white figure --> draw
        if (new_s.white_turn()) {
            if (new_s.black_king == new_s.vizir || 
                new_s.black_king == new_s.verbloud) {
                pair<string, int> res = {DRAW, 0};
                result[s.get_hash()] = res;

                return res;
            }
        }
        results.push_back(rec(new_s, depth + 1));
    }
    if (s.white_turn()) {
        if (all_equals(results, DRAW)) {
            pair<string, int> res = {DRAW, 0};
            result[s.get_hash()] = res;
            return res;
        } else {
            int mn = INF;
            for (auto result : results) {
                if (result.first == WIN) {
                    mn = min(mn, result.second);
                }
            }
            pair<string, int> res = pair<string, int>{WIN, mn + 1};
            result[s.get_hash()] = res;
            return res;
        }
    } else {
        if (all_equals(results, WIN)) {
            int mx = -INF;
            for (auto result : results) {
                mx = max(mx, result.second);
            }
            pair<string, int> res = pair<string, int>{WIN, mx};
            result[s.get_hash()] = res;
            return res;
        } else {
            pair<string, int> res = {DRAW, 0};
            result[s.get_hash()] = res;
            return res;
        }
    }
}

void solve() {
    state start;
    cin >> start.white_king >> start.black_king >> start.verbloud >> start.vizir >> start.turn;
    // cout << "kek" << endl;
    // return;
    pair<string, int> res = rec(start);
    if (res.first == WIN) {
        cout << "#" << res.second << "\n";
    } else {
        cout << "0\n";
    }
}

signed main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);
#ifdef FSTREAM
    freopen("input_chess.txt", "r", stdin);
    freopen("output_chess.txt", "w", stdout);
#endif
    size_t t = 1;
#ifdef MULTITEST
    cin >> t;
#endif
    for (size_t i = 0; i < t; ++i) {
        solve();
    }
    return 0;
}