#include <algorithm>
#include <cassert>
#include <iostream>
#include <vector>
#include <set>
#include <numeric>

using namespace std;
using ll = long long;
using vl = vector<ll>;

istream &operator>>(istream &os, vl &a) {
    for (auto &x: a) cin >> x;
    return os;
}

#define int long long

template<typename T, T (*f)(T, T), T (*e)()>
struct SegTree {
    int n;
    vector<T> sgt;

    explicit SegTree(int size) {
        n = size;
        sgt = vector<T>(4 * size);
    }

    void build(vector<T> &d, int c, int l, int r) {
        if (l == r) sgt[c] = d[l];
        else {
            int m = (r + l) / 2;
            build(d, 2 * c, l, m);
            build(d, 2 * c + 1, m + 1, r);
            sgt[c] = f(sgt[2 * c], sgt[2 * c + 1]);
        }
    }

    T ask(int c, int l, int r, int lq, int rq) {
        if (rq < l || r < lq) return e();
        if (lq <= l && r <= rq) return sgt[c];
        int m = (r + l) / 2;
        return f(ask(2 * c, l, m, lq, rq), ask(2 * c + 1, m + 1, r, lq, rq));
    }

    void update(int c, int l, int r, int pos, T val) {
        if (l == r) sgt[c] = val;
        else {
            int m = (r + l) / 2;
            (pos <= m) ? update(2 * c, l, m, pos, val) : update(2 * c + 1, m + 1, r, pos, val);
            sgt[c] = f(sgt[2 * c], sgt[2 * c + 1]);
        }
    }
};

int op(int a, int b) {
    return gcd(a, b);
}

int e() {
    return 0LL;
}

signed main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    int n;
    cin >> n;
    vector<int> a(n + 1);
    for (int i = 1; i <= n; i++) cin >> a[i];
    int s, f;
    cin >> s >> f;
    SegTree<int, op, e> H(n);
    for (int i = 1; i <= n - 1; i++) H.update(1, 0, n - 1, i, abs(a[i + 1] - a[i]));
    vector<int> next_can_go(n + 1, -1), good(n + 1, -1);
    for (int i = 1; i <= n; i++) next_can_go[i] = i, good[i] = 0;
    for (int i = 1; i <= n; i++) {
        if (i == n) continue;
        if (abs(a[i + 1] - a[i]) == 1) continue;
        int l = i + 1, r = n;
        while (r - l > 1) {
            int m = (r + l) / 2;
            if (H.ask(1, 0, n - 1, i, m - 1) == 1) r = m;
            else l = m;
        }
        next_can_go[i] = l;
        good[i] = H.ask(1, 0, n - 1, i, l - 1);
    }
    bool fl = s > f;
    if (s > f) swap(s, f);
    vector<int> dp(n + 1, -1);
    vector<int> from(n + 1, -1);
    dp[s] = 0;
    vector<int> min_can(n + 1, n + 1);
    for (int i = 1; i <= n; i++) min_can[i] = i;

    vector<pair<int, int>> st;
    for (int i = 1; i <= n; i++) st.emplace_back(i, next_can_go[i]);
    sort(st.begin(), st.end(), [&](pair<int, int> &x, pair<int, int> &y) {
        return x.second < y.second;
    });
    reverse(st.begin(), st.end());
    for (auto &[x, y]: st) {
        min_can[y] = min(x, min_can[y]);
    }
    for (int i = n - 1; i >= 1; i--) {
        min_can[i] = min(min_can[i], min_can[i + 1]);
    }
   // for (int i = 1; i <= n; i++) cout << i << " " << next_can_go[i] << "\n";
    bool flag = true;
    for (int ff = s + 1; ff <= f; ff++) {
        auto fr = min_can[ff];
        fr = max(fr, s);
        if (fr == ff) flag = false;
        dp[ff] = dp[fr] + 1;
        from[ff] = fr;
    }
    for (int i = s; i <= f; i++) {
      //  cout << from[i] << " ";
    }

    vector<pair<int, int>> answer;
    if (!flag) {
        cout << "Impossible\n";
        return 0;
    }
    int cur = f;
    while (cur != s) {
        //cout << cur << "!\n";
        int fff = from[cur];
        int gc = H.ask(1, 0, n - 1, fff, cur - 1);
        if (gc == 0) gc = 2;
        answer.emplace_back(fff, cur);
        cur = from[cur];
    }
    vector<pair<string, pair<int, int>>> qwe;
     if (!fl) {
        for (auto &[x, y]: answer) {
            int gc = H.ask(1, 0, n - 1, x, y - 1);
            if (gc == 0) gc = 2;
            qwe.push_back({"Kaban-" + to_string(gc), {x, y}});
            //cout << "Kaban-" << gc << " " << x << " " << y << "\n";
        }
         reverse(qwe.begin(), qwe.end());
    }else {
        for (auto &[x, y]: answer) {
            int gc = H.ask(1, 0, n - 1, x, y - 1);
            if (gc == 0) gc = 2;
            qwe.push_back({"Kaban-" + to_string(gc), {x, y}});
            //cout << "Kaban-" << gc << " " << x << " " << y << "\n";
        }
        //reverse(qwe.begin(), qwe.end());
        for (auto &[x, y]: qwe) {
            swap(y.first, y.second);
        }
    }
    for (auto &d: qwe) {
        cout << d.first << " " << d.second.first << " " << d.second.second << "\n";
    }
}
