#include <iostream>
#include <vector>
#include <map>
#include <cstdint>
#include <cassert>
#include <algorithm>
#include <queue>
#include <set>

using namespace std;

const int N = (1 << 24) * 2;
const int INF = 1e9;
int dp[N]; // INF - ничья, иначе - минимальное кол-во ходов для мата
int cnt[N];
vector<int> graph[N];
bool killable[N];

pair<int, int> horse_moves[8]{
        {1,  3},
        {3,  1},
        {3,  -1},
        {1,  -3},
        {-1, -3},
        {-3, -1},
        {-3, 1},
        {-1, 3},
};

pair<int, int> vizer_moves[4]{
        {1,  0},
        {-1, 0},
        {0,  -1},
        {0,  1},
};

pair<int, int> king_moves[9]{
        {-1, -1},
        {-1, 0},
        {-1, 1},
        {0,  -1},
        {0,  0},
        {0,  1},
        {1,  -1},
        {1,  0},
        {1,  1},
};

struct state {
    int ih, jh; // конь
    int iv, jv; // визирь
    int ik, jk; // король
    int ib, jb; // черный король
    int who; // чей ход
};

state decode(int v) {
    state s;

    s.who = v & 1;
    v >>= 1;
    s.jh = v & 7;
    v >>= 3;
    s.ih = v & 8;
    v >>= 3;
    s.jv = v & 7;
    v >>= 3;
    s.iv = v & 7;
    v >>= 3;
    s.jk = v & 7;
    v >>= 3;
    s.ik = v & 7;
    v >>= 3;
    s.jb = v & 7;
    v >>= 3;
    s.ib = v & 7;
    v >>= 3;
    assert(v == 0);

    return s;
}

int encode(state s) {
    int v = 0;

    v = (v << 3) + s.ib;
    v = (v << 3) + s.jb;

    v = (v << 3) + s.ik;
    v = (v << 3) + s.jk;

    v = (v << 3) + s.iv;
    v = (v << 3) + s.jv;

    v = (v << 3) + s.ih;
    v = (v << 3) + s.jh;

    v = (v << 1) + s.who;

    return v;
}


pair<int, int> parse(const string &s) {
    return {8 - (s[1] - '0'), s[0] - 'a'};
}

bool ok_move(state s, int i, int j) {
    if (i < 0 || j < 0 || i >= 8 || j >= 8)
        return false;
    if (i == s.ib && j == s.ib)
        return false;
    if (i == s.ih && j == s.ih)
        return false;
    if (i == s.iv && j == s.iv)
        return false;
    if (i == s.ik && j == s.ik)
        return false;
    return true;
}

bool horse_kills_black(state s) {
    for (auto[di, dj] : horse_moves) {
        if (s.ih + di == s.ib && s.jh + dj == s.jb)
            return true;
    }
    return false;
}

bool vizir_kills_black(state s) {
    for (auto[di, dj] : vizer_moves) {
        if (s.iv + di == s.ib && s.jv + dj == s.jb)
            return true;
    }
    return false;
}

bool king_kills_black(state s) {
    for (auto[di, dj] : king_moves) {
        if (s.ik + di == s.ib && s.jk + dj == s.jb)
            return true;
    }
    return false;
}

bool white_under_shah(state s) {
    return max(abs(s.ik - s.ib), abs(s.jk - s.jb)) <= 1;
}

bool black_under_shah(state s) {
    if (horse_kills_black(s))
        return true;
    if (vizir_kills_black(s))
        return true;
    if (king_kills_black(s))
        return true;
    return false;
}

bool black_cant_move(state s) {
    if (s.who == 0) return false;
    for (int di = -1; di <= 1; ++di) {
        for (int dj = -1; dj <= 1; ++dj) {
            if (di == 0 && dj == 0) continue;
            int i1 = s.ib + di, j1 = s.jb + dj;
            if (!ok_move(s, i1, j1))
                continue;
            auto to = s;
            to.ib = i1, to.jb = j1;
            if (!black_under_shah(to))
                return false;
        }
    }
    return true;
}

bool mat(state s) {
    return black_cant_move(s) && black_under_shah(s);
}

bool pat(state s) {
    return black_cant_move(s) && !black_under_shah(s);
}

void bfs() {
    queue<int> q;
    for (int v = 0; v < N; ++v) {
        state s = decode(v);
        if (killable[v]) {
            cnt[v] = 0;
            dp[v] = INF;
            q.push(v);
            continue;
        }
        if (cnt[v] == 0) {
            if (mat(s)) dp[v] = 0;
            else {
                dp[v] = INF;
            }
            q.push(v);
        }
    }
    while (!q.empty()) {
        int v = q.front();
        q.pop();
        for (int from : get_graph[v]) {
            if (decode(v).who == 1) {
                if (dp[from] == -1)
                    dp[from] = dp[v] + 1;
                else
                    dp[from] = min(dp[from], dp[v] + 1);
            } else {
                dp[from] = max(dp[from], dp[v]);
            }
            --cnt[from];
            if (cnt[from] == 0)
                q.push(from);
        }
    }
}

void solve() {
    string s1, s2, s3, s4;
    cin >> s1 >> s2 >> s3 >> s4;
    string w;
    cin >> w;
    int who = (w == "b");
    auto[ik, jk] = parse(s1);
    auto[ib, jb] = parse(s2);
    auto[ih, jh] = parse(s3);
    auto[iv, jv] = parse(s4);
    int v = encode({ih, jh, iv, jv, ik, jk, ib, jb, who});
    if (dp[v] < INF && dp[v] != -1) cout << "#" << dp[v] << "\n";
    else cout << "0\n";
}

void calc_transitions(int v) {
    state s = decode(v);
    if (s.who == 0) { // белые ходят
        { // визерем
            for (auto[di, dj] : vizer_moves) {
                if (ok_move(s, s.iv + di, s.jv + dj)) {
                    auto to = s;
                    to.iv += di, to.jv += dj;
                    to.who ^= 1;
                    graph[encode(to)].push_back(v);
                }
            }
        }

        { // конём
            for (auto[di, dj] : horse_moves) {
                if (ok_move(s, s.ih + di, s.jh + dj)) {
                    auto to = s;
                    to.ih += di, to.jh += dj;
                    to.who ^= 1;
                    graph[encode(to)].push_back(v);
                }
            }
        }

        { // королём
            for (auto[di, dj] : king_moves) {
                if (ok_move(s, s.ik + di, s.jk + dj)) {
                    auto to = s;
                    to.ik += di, to.jk += dj;
                    to.who ^= 1;
                    graph[encode(to)].push_back(v);
                }
            }
        }
    } else {
        for (auto[di, dj] : king_moves) {
            if (s.ib + di == s.ih && s.jb + dj == s.jh) { // съели коня
                auto to = s;
                to.ib += di, to.jb += dj;
                if (!black_under_shah(to)) {
                    killable[v] = true;
                    break;
                }
            }
            if (s.ib + di == s.iv && s.jb + dj == s.jv) { // съели визиря
                auto to = s;
                to.ib += di, to.jb += dj;
                if (!black_under_shah(to)) {
                    killable[v] = true;
                    break;
                }
            }
            if (ok_move(s, s.ib + di, s.jb + dj)) {
                auto to = s;
                to.ib += di, to.jb += dj;
                to.who ^= 1;
                graph[encode(to)].push_back(v);
            }
        }
    }
}

bool invalid(int v) {
    state s = decode(v);
    set<pair<int, int>> coords{
            {s.ih, s.jh},
            {s.iv, s.jv},
            {s.ik, s.jk},
            {s.ib, s.jb},
    };
    return coords.size() == 4;
}

int32_t main() {
    std::ios_base::sync_with_stdio(false);
    std::cin.tie(nullptr);
    std::cout.precision(20);

    fill(dp, dp + N, -1);
    for (int v = 0; v < N; ++v) {
        if (invalid(v))
            continue;
        calc_transitions(v);
        cnt[v] = graph[v].size();
    }
    bfs();

    int T;
    cin >> T;
    while (T--)
        solve();
}