#include <iostream>
#include <random>
#include <vector>
#include <ctime>
#define ll long long

using namespace std;

constexpr ll MOD = 998'244'353;

std::mt19937_64 rnd(time(0));

struct carttree {

  using node_ptr = ll;

  node_ptr root = -1;

  void insert(ll pos, ll val) {
    auto q = create_node(val);
    if (root == -1) {
      root = q;
      return;
    }
    auto tt = split_by_pos(root, pos);
    root = merge(merge(tt.first, q), tt.second);
  }

  void remove(ll pos) {
    auto tt1 = split_by_pos(root, pos);
    if (tt1.second == -1) {
      return;
    }
    // cout << "First split: ";
    // print(tt1.first, cout);
    // cout << " | ";
    // print(tt1.second, cout);
    // cout << endl;
    auto tt2 = split_by_pos(tt1.second, 1);
    // cout << "Second split: ";
    // print(tt2.first, cout);
    // cout << " | ";
    // print(tt2.second, cout);
    // cout << endl;
    root = merge(tt1.first, tt2.second);
  }

  pair<ll, ll> get_min(ll x, ll y) {
    // cout << x << " " << y << endl;
    auto tt1 = split_by_pos(root, y);
    auto tt2 = split_by_pos(tt1.first, x);
    // std::cout << "get_min: ";
    // print(tt2.first, cout);
    // cout << " " << get_mn(tt2.first).first << " | ";
    // print(tt2.second, cout);
    // cout << " " << get_mn(tt2.second).first << " | ";
    // print(tt1.second, cout);
    // cout << " " << get_mn(tt1.second).first << endl;
    auto res = get(tt2.second).mn;
    res.second += get_am(tt2.first);
    root = merge(merge(tt2.first, tt2.second), tt1.second);
    // print(root, cout);
    // cout << endl;
    return res;
  }

  void print(ostream &out) { print(root, out); }

private:
  void print(node_ptr h, ostream &out) {
    if (h == -1) {
      return;
    }
    print(get(h).l, out);
    out << get(h).val;
    print(get(h).r, out);
  }

  node_ptr create_node(ll val) {
    node_ptr nd = nodes.size();
    nodes.push_back(node(val));
    return nd;
  }

  struct node {

    node(ll val) : val(val), mn({val, 0}) {}

    ll val;
    ll am = 1;
    ll y = rnd();
    pair<ll, ll> mn;
    ll l = -1, r = -1;
  };

  node &get(node_ptr h) { return nodes[h]; }

  ll get_am(node_ptr h) {
    if (h == -1) {
      return 0;
    } else {
      return get(h).am;
    }
  }

  pair<ll, ll> get_mn(node_ptr h) {
    if (h == -1) {
      return {1e9 + 5, -1};
    } else {
      return get(h).mn;
    }
  }

  void upd(node_ptr h) {
    if (h == -1) {
      return;
    }

    get(h).am = 1 + get_am(get(h).l) + get_am(get(h).r);

    pair<ll, ll> p1 = get_mn(get(h).l);
    pair<ll, ll> p2{get(h).val, get_am(get(h).l)};
    pair<ll, ll> p3 = get_mn(get(h).r);
    p3.second += 1 + get_am(get(h).l);
    if (p1 <= p2 && p1 <= p3) {
      get(h).mn = p1;
    } else if (p2 <= p1 && p2 <= p3) {
      get(h).mn = p2;
    } else {
      get(h).mn = p3;
    }
  }

  node_ptr merge(node_ptr l, node_ptr r) {
    if (l == -1) {
      return r;
    }
    if (r == -1) {
      return l;
    }
    if (get(l).y >= get(r).y) {
      get(l).r = merge(get(l).r, r);
      upd(l);
      return l;
    } else {
      get(r).l = merge(l, get(r).l);
      upd(r);
      return r;
    }
  }

  pair<node_ptr, node_ptr> split_by_pos(node_ptr h, ll pos) {
    if (h == -1) {
      return {-1, -1};
    }
    if (get(h).am <= pos) {
      return {h, -1};
    }
    if (pos == 0) {
      return {-1, h};
    }
    // cout << h << " :: " << get_am(get(h).l) << " " << get_am(get(h).r) << endl;
    if (get_am(get(h).l) >= pos) {
      auto tt = split_by_pos(get(h).l, pos);
      get(h).l = -1;
      upd(h);
      return {tt.first, merge(tt.second, h)};
    } else {
      auto tt = split_by_pos(get(h).r, pos - get_am(get(h).l) - 1);
      get(h).r = -1;
      upd(h);
      return {merge(h, tt.first), tt.second};
    }
  }

  vector<node> nodes;
};

void solve() {
  string s;
  ll k;
  cin >> s >> k;
  ll n = s.size();
  carttree cr;
  for (ll i = 0; i < s.size(); i++) {
    cr.insert(i, s[i] - '0');
  }
  ll j = 0;
  while (j < n && k > 0) {
    auto rs = cr.get_min(j, j + k + 1);
    // cout << rs.first << " " << rs.second << endl;
    if (rs.second == j) {
      j++;
    } else {
      cr.remove(rs.second);
      cr.insert(j, rs.first);
      k -= rs.second - j;
      j++;
    }
    // cout << j << " : ";
    // cr.print(cout);
    // cout << endl;
  }
  cr.print(cout);
  cout << endl;
}

int main() {
  ios_base::sync_with_stdio(0);
  cin.tie(0);
  ll t = 1;
  cin >> t;
  while (t--) {
    solve();
  }
}

/*
6 1 3
1 5 8
5 3 2
6 5 9
2 1 4
2 4 6
1 2
12 3
15 6
4 3
10 2
*/