#include <cstdint>
#include <iostream>
#include <ostream>
#include <unordered_map>

struct Key {
  std::uint64_t r;
  std::uint64_t g;
  std::uint64_t b;
  char added_ball;

  bool operator==(const Key &other) const {
    return r == other.r && g == other.g && b == other.b &&
           added_ball == other.added_ball;
  }
};

namespace std {
template <> struct hash<Key> {
  std::size_t operator()(const Key &k) const {
    return ((std::hash<std::uint64_t>()(k.r) ^
             (std::hash<std::uint64_t>()(k.g) << 1)) >>
            1) ^
           (std::hash<std::uint64_t>()(k.b) << 1) ^
           (std::hash<char>()(k.added_ball) << 1);
  }
};
} // namespace std

std::uint64_t solve(const std::uint64_t r, const std::uint64_t g,
                    const std::uint64_t b, const char added_ball = 'n') {
  if (r + g + b == 0) {
    return 1;
  }

  std::uint64_t res = 0;

  if (added_ball != 'r' && r > 0)
    res += solve(r - 1, g, b, 'r');

  if (added_ball != 'g' && g > 0)
    res += solve(r, g - 1, b, 'g');

  if (added_ball != 'b' && b > 0)
    res += solve(r, g, b - 1, 'b');

  return res % 998'244'353;
}

std::uint64_t cache_solve(const std::uint64_t r, const std::uint64_t g,
                          const std::uint64_t b, const char added_ball = 'n') {
  static std::unordered_map<Key, std::uint64_t> cache;

  Key key = {r, g, b, added_ball};

  auto it = cache.find(key);
  if (it != cache.end()) {
    return it->second;
  }

  std::uint64_t result = solve(r, g, b, added_ball);
  cache[key] = result;

  return result;
}

bool check(std::uint64_t const &r, std::uint64_t const &g,
           std::uint64_t const &b) {
  return !(r > g + b + 1 || g > r + b + 1 || b > r + g + 1);
}

int main() {
  std::ios_base::sync_with_stdio(false);
  std::cin.tie(0);
  std::cout.tie(0);

  std::uint64_t r, g, b;
  std::cin >> r >> g >> b;

  if (check(r, g, b)) {
    std::cout << solve(r, g, b) << std::endl;
  } else {
    std::cout << 0 << std::endl;
  }

  return 0;
}
